
# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

"""
Worker for memory.
"""
#import psutil
from vsm import utils

class MemoryWorker(object):
    """Worker for Memory."""
    def __init__(self):
        pass

#    def get_mem_total(self):
#        mem = psutil.virtual_memory()
#        return mem.total

    #def get_mem_available(self):
    #    mem = psutil.virtual_memory()
    #    return mem.available
